pub struct DeviceValidity {
pub device_desc: Option<DeviceDescriptor>,
pub is_valid: Option<bool>,
pub reason: Option<String>,
}Expand description
The device validity element describes whether a particular device is valid to operate in the regulatory domain.
This type is not used in any activity, and only used as part of another schema.
Fields
device_desc: Option<DeviceDescriptor>The descriptor of the device for which the validity check was requested. It will always be present.
is_valid: Option<bool>The validity status: true if the device is valid for operation, false otherwise. It will always be present.
reason: Option<String>If the device identifier is not valid, the database may include a reason. The reason may be in any language. The length of the value should not exceed 128 characters.