pub struct EventTime {
pub start_time: Option<String>,
pub stop_time: Option<String>,
}Expand description
The start and stop times of an event. This is used to indicate the time period for which a spectrum profile is valid.
Both times are expressed using the format, YYYY-MM-DDThh:mm:ssZ, as defined in RFC3339. The times must be expressed using UTC.
This type is not used in any activity, and only used as part of another schema.
Fields
start_time: Option<String>The inclusive start of the event. It will be present.
stop_time: Option<String>The exclusive end of the event. It will be present.